# DOCUMENTATION



## <left> Why NeuralForecast </left>

`NeuralForecast` is a time-series forecasting library with deep learning models.
<br>
##### Why Deep Learning
- Highly Accurate Predictions: 
    - High capacity shared models across panel data time series.
- Fast and Efficient Models: 
    - Automatic featurization provided by the networks information processes.
    - Fast GPU computations.

##### NeuralForecast Features
- Easy-to-use state-of-the-art models: 
	- Dataset, dataloader and evaluation utility.
	- Code organization follows Lightning. Pure PyTorch without boilerplate.
	- Implementations of high performing forecasting models with minimal entry barriers.
- High Efficiency and low computation costs:
	- Fast dataloaders and model optimization.
	- Scalable to any hardware without changing the models.
<br>

<br>
<br>

## <left> Tutorial 1: Installation and Introduction <left>

## <left> Tutorial 2: Time Series DataSets and DataLoaders <left>

## <left> Tutorial 3: Model Training and Evaluation <left>

## <left> Tutorial 4: Production Deployment <left>

## <left> Community <left>

Slack, twitter, something else
